perl_app_perlbrew: Perl installation management tool
====================================================

perlbrew is an admin-free perl installation management tool.


License
-------

MIT


Upstream Contact
----------------

- https://perlbrew.pl/
- https://metacpan.org/pod/App::perlbrew
- https://github.com/gugod/App-perlbrew
